@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::Util::ConfigDumper;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.002001';
 
 # ABSTRACT: Easy implementation of 'dumpconfig'
 
@@ -52,12 +52,12 @@ sub _mk_method_test {
 }
 
 sub _mk_attribute_test {
-  my ( $package, $attrname ) = @_;
-  my $metaclass           = $package->meta;
-  my $attribute_metaclass = $metaclass->get_attribute($attrname);
+  my ( undef, $attrname ) = @_;
   return sub {
     my ( $instance, $payload, $fails ) = @_;
     try {
+      my $metaclass           = $instance->meta;
+      my $attribute_metaclass = $metaclass->get_attribute($attrname);
       if ( $attribute_metaclass->has_value($instance) ) {
         $payload->{$attrname} = $attribute_metaclass->get_value($instance);
       }
@@ -99,7 +99,7 @@ Dist::Zilla::Util::ConfigDumper - Easy implementation of 'dumpconfig'
 
 =head1 VERSION
 
-version 0.002000
+version 0.002001
 
 =head1 SYNOPSIS
 
